@@ -39,6 +39,9 @@ pub struct Builder {
 
     /// The filter environment variable to use for `tracing` events.
     pub(super) filter_env_var: String,
+
+    /// Whether to trace events coming from the subscriber thread
+    self_trace: bool,
 }
 
 impl Default for Builder {
@@ -51,6 +54,7 @@ impl Default for Builder {
             server_addr: SocketAddr::new(Server::DEFAULT_IP, Server::DEFAULT_PORT),
             recording_path: None,
             filter_env_var: "RUST_LOG".to_string(),
+            self_trace: false,
         }
     }
 }
@@ -176,6 +180,15 @@ impl Builder {
         }
     }
 
+    /// Sets whether tasks, resources, and async ops from the console
+    /// subscriber thread are recorded.
+    ///
+    /// By default, events from the console subscriber are discarded and
+    /// not exported to clients.
+    pub fn enable_self_trace(self, self_trace: bool) -> Self {
+        Self { self_trace, ..self }
+    }
+
     /// Completes the builder, returning a [`ConsoleLayer`] and [`Server`] task.
     pub fn build(self) -> (ConsoleLayer, Server) {
         ConsoleLayer::build(self)
@@ -368,6 +381,8 @@ impl Builder {
             meta.name().starts_with("runtime.") || meta.target().starts_with("tokio")
         }
 
+        let self_trace = self.self_trace;
+
         let (layer, server) = self.build();
         let filter =
             FilterFn::new(console_filter as for<'r, 's> fn(&'r tracing::Metadata<'s>) -> bool);
@@ -376,6 +391,12 @@ impl Builder {
         thread::Builder::new()
             .name("console_subscriber".into())
             .spawn(move || {
+                let _subscriber_guard;
+                if !self_trace {
+                    _subscriber_guard = tracing::subscriber::set_default(
+                        tracing_core::subscriber::NoSubscriber::default(),
+                    );
+                }
                 let runtime = runtime::Builder::new_current_thread()
                     .enable_io()
                     .enable_time()
